# SendDiff script to atomate the diff mail send on cvs commit
# Copyright (C) 2002-04  Mahdi Hannoun <mhd@arakhne.org>,
#                        Stephane Galland <galland@arakhne.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

=pod

=head1 NAME

SendDiff::Array - Array maipulation

=head1 DESCRIPTION

SendDiff::Array is a Perl module which permits to use Array.

=cut
package SendDiff::Array;
@ISA = ('Exporter');
@EXPORT = qw( &isarray &mergearray &inarray ) ;
@EXPORT_OK = qw();
use strict;
use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
my $VERSION = "0.2" ;

=pod

=head1 FUNCTION DESCRIPTIONS

This section contains only the functions in Array.pm itself.

=over

=item * isarray(REFERENCE)

Replies if the specified struct is an array.
Takes 1 arg:

=over

=item REFERENCE is the object to test (array reference).

=back

=cut
sub isarray($) {
  return 0 unless defined($_[0]) ;
  my $r = ref( $_[0] ) ;
  return ( $r eq "ARRAY" ) ;
}

=pod

=item * mergearray(ARRAY, [ARRAY...])

Merge recursively the arrays.
Takes n args:

=over

=item ARRAY is an array, or a reference to an array.

=back

=cut
sub mergearray {
  my @s = @_ ;
  my @a = () ;
  while (@s) {
    my $e = shift @s ;
    if (isarray($e)) {
      unshift @s, @{$e} ;
    }
    else {
      push @a, $e ;
    }
  }
  return @a ;
}

=pod

=item * inarray(ARRAY, [COMPONENT...])

Replies the count of elements found inside the array. The test is lexicographic.
Takes n args:

=over

=item ARRAY is an array.

=item COMPONENT is a element to search into the ARRAY.

=back

=cut
sub inarray(\@$) {
  my $tab = shift;
  my $found = 0;
  foreach my $search (@_) {
    my $bfound = undef;
    foreach my $elt (@{$tab}) {
      if ("$elt" eq "$search") {
        $bfound = 1;
      }
    }
    if ($bfound) {
      $found = $found + 1;
    }
  }
  return $found;
}

1;
__END__

=back
