# SendDiff script to atomate the diff mail send on cvs commit
# Copyright (C) 2002-04  Mahdi Hannoun <mhd@arakhne.org>,
#                        Stephane Galland <galland@arakhne.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

=pod

=head1 NAME

SendDiff::Cvs::User - Extractor of the Cvs's user list

=head1 DESCRIPTION

SendDiff::Cvs::User is a Perl module which implementes an
extractor of the Cvs's user list.

=cut
package SendDiff::Cvs::User;
@ISA = ('Exporter');
@EXPORT = qw( &getCVSUserFile &getCVSUserFilename &getCVSUserForGroup ) ;
@EXPORT_OK = qw();
use strict;
use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
my $VERSION = "0.3" ;

use File::Spec ;

use SendDiff::Array ;

=pod

=head1 FUNCTION DESCRIPTIONS

This section contains only the functions in User.pm itself.

=over

=item * getCVSUserFile(FILE,[GROUP])

Reads the receivers' emails and logins from a Cvs user file.
Takes 2 args:

=over

=item FILE is the path to the file to read (scalar)

=item GROUP is the name of the Unix user's group to use (scalar)

=back

=cut
sub getCVSUserFile($;$) {
  if ( $_[1] ) {
    return getCVSUserForGroup("$_[1]");
  }
  elsif ( ( $_[0] ) &&
       ( -f "$_[0]" ) &&
       ( -r "$_[0]" ) ) {
    local *USERS ;
    my %adr = () ;
    local *USERS ;
    open( *USERS, "< $_[0]" )
      or safeQuit( "Unable to open $_[0]: $!" ) ;
    while( my $line = <USERS> ) {
      chomp($line);
      if ( $line ) {
	my @fields = split(':',$line) ;
	my $login = $fields[0] ;
	my $email = $fields[1] ;
	chomp($login) if ( $login ) ;
	chomp($email) if ( $email ) ;
 	if (($email)&&($login)) {
	  $adr{"$login"} = "$email" ;
 	}
      }
    }
    close( *USERS ) ;
    return %adr ;
  }
  return () ;
}

=pod

=item * getCVSUserFilename(BASE)

Replies the filename of the user file
Takes 1 arg:

=over

=item BASE is the base path to the file to read (scalar)

=back

=cut
sub getCVSUserFilename($) {
  return File::Spec->catfile($_[0],'CVSROOT','users');
}

=pod

=item * getCVSUserForGroup(GROUP)

Replies the users' emails that are in the specified group
Takes 1 arg:

=over

=item GROUP is the name of the group (scalar)

=back

=cut
sub getCVSUserForGroup($) {
  my $cvsgroup = shift;
  if ( $cvsgroup ) {
    my (undef,undef,$gid,$members) = getgrnam("$cvsgroup");
    if ($gid) {
      my @members = split(/[ \t]+/,$members);
      #($name,$passwd,$uid,$gid,$quota,$comment,$gcos,$dir,$shell,$expire) = getpw*
      my %list = ();
      while (my ($login,undef,undef,$ugid,undef,undef,undef,$home) = getpwent()) {
        if ((($gid == $ugid)||
             (inarray(@members,$login)))&&
            (!isUserWouldIgnoreCVSNotification("$cvsgroup","$home"))) {

          # Read the first email into the file '.forward'
          my $email = readEmailForward("$home");
          if ($email) {
            $list{"$login"} = "$email";
          }
          else {
            $list{"$login"} = "$login";
          }

        }
      }
      endpwent();
      return %list;
    }
  }
  return () ;
}

=pod

=item * readEmailForward(HOME)

Read the first email address from the file $HOME/.forward.

=over

=item HOME is the path of the user's home directory (scalar)

=back

=cut
sub readEmailForward($) {
  my $home = shift;
  my $forward_file = File::Spec->catfile($home,'.forward');
  if (-r "$forward_file") {
    local *FORWARDFILE;
    open(*FORWARDFILE, "< $forward_file");
    my $line = <FORWARDFILE>;
    close(*FORWARDFILE);
    if ($line =~ /@/) {
      $line =~ s/^\s//;
      $line =~ s/\s$//;
      return "$line";
    }
  }
  return undef;
}

=pod

=item * isUserWouldIgnoreCVSNotification(GROUP,HOME)

Replies if the given user would ignore CVS notifications.

=over

=item GROUP is the name of the CVS group (scalar)

=item HOME is the path of the user's home directory (scalar)

=back

=cut
sub isUserWouldIgnoreCVSNotification($$) {
  my $cvsgroup = shift;
  my $home = shift;
  my $ignore_file = File::Spec->catfile($home,'.ignore_cvs_notification');
  if (-r "$ignore_file") {
    local *IGNOREFILE;
    open(*IGNOREFILE, "< $ignore_file");
    my @lines = <IGNOREFILE>;
    close(*IGNOREFILE);

    return 1 unless (@lines);

    foreach my $line (@lines) {
      $line =~ s/^\s+//g;      
      $line =~ s/\s+$//g;      
      if ("$cvsgroup" eq "$line") {
        return 1;
      }
    }

  }
  return undef;
}

1;
__END__

=back
