# SendDiff script to atomate the diff mail send on cvs commit
# Copyright (C) 2002-04  Mahdi Hannoun <mhd@arakhne.org>,
#                        Stephane Galland <galland@arakhne.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

=pod

=head1 NAME

SendDiff::Error - Error reporting

=head1 DESCRIPTION

SendDiff::Error is a Perl module, which proposes
functions for error and warning reports.

=head1 FUNCTION DESCRIPTIONS

This section contains only the functions in Error.pm itself.

=over

=cut
package SendDiff::Error;
@ISA = ('Exporter');
@EXPORT = qw( &safeQuit &safeWarning &verboselevel &verbose ) ;
@EXPORT_OK = qw();
use strict;
use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
my $VERSION = "0.1" ;

# ------------------------- Global variables ---
my $VERBOSE_LEVEL = 1 ;
# ----------------------------------------------

=pod

=item * safeQuit(MESSAGE)

Display the specified error message and safely quit.
Takes 1 arg:

=over

=item MESSAGE is the error message (scalar).

=back

=cut
sub safeQuit($) {
  die( "senddiff.pl: $_[0]\n" ) ;
}

=pod

=item * safeWarning(MESSAGE)

Display the specified error message.
Takes 1 arg:

=over

=item MESSAGE is the error message (scalar).

=back

=cut
sub safeWarning($) {
  print STDERR ( "senddiff.pl: $_[0]\n" ) ;
}

=pod

=item * verboselevel([LEVEL])

Sets or replies the verbose level. If the level was equal to
0 the script is quiet.
Takes 1 arg:

=over

=item LEVEL is the verbose level (scalar).

=back

=cut
sub verboselevel(;$) {
  if (@_>=1) {
    $VERBOSE_LEVEL = int($_[0]) ;
    $VERBOSE_LEVEL = 0 
      if ( $VERBOSE_LEVEL < 0 ) ;
  }
  return $VERBOSE_LEVEL ;
}

=pod

=item * verbose(MESSAGE,[LEVEL])

Display the message if allowed.
Takes 2 args:

=over

=item MESSAGE is the message to display (scalar).

=item LEVEL is the verbosing level at which the message must be displayed (scalar).

=back

=cut
sub verbose($;$) {
  my $level = 1 ;
  $level = int($_[1]) if (@_>=2) ;
  $level = 1 if ( $level <= 0 ) ;
  if ( $level <= $VERBOSE_LEVEL ) {
    my $msg = $_[0] || '' ;
    chomp($msg);
    print STDOUT "$msg\n" ;
  }
}

1;
__END__

=back
